

*		************************************************************************		*
*		************************************************************************		*
*		  File:				main.do														*
*		  Date:				July 2017													*
*		  Purpose:			Tables/Figures reported in Sambanis et al. (2017)			*
*		  Log file:			SDM.log														*
*		  Stata version:	14															*
*		************************************************************************		*
*		************************************************************************		*




***************
** Preparations
***************


* Set directory
cd "...\Supplementary materials\Replication" /* Set to respective directory */


* Log
capture log close
log using "SDM.log", replace

* Packages
ssc install distinct, replace
ssc install labutil2, replace 
 

 

**********
** Table 1
**********

* Get data
use "SDM_final.dta", replace


*
** Global
*

* SDMs 
distinct groupid //=464

* Countries 
distinct ccode // =120

* Average years of activity
count if active ==1 // =13988
display 13988/464 // = 30.146552

* Ongoing SDMs (2012)
gen ongoing = 0 if active == 1
replace ongoing = 1 if enddate1 == 9999 | enddate2 == 9999
distinct groupid if ongoing == 1 // =327

* SDMs with two phases of activity 
distinct groupid if fyphase2==1 // =36

* Violent SDMs 
count if fygroup==1 & violent==1 // =150

* Average years until first violence 
gen violyear = year if violsd == 1
bysort groupid: egen rank = rank(violyear)
gen minyear = violyear if rank == 1
bysort groupid: egen meanyear = mean(minyear)
gen untilfirstviol = 1 if active == 1 & year <= meanyear & meanyear != .
bysort groupid: egen durationuntilviolence = max(duration) if untilfirstviol == 1
sum durationuntilviolence if untilfirstviol == 1 & fyphase1 == 1 // =6.55



**********
** Table 2
**********


* Get data
use "SDM_final.dta", replace


* All concessions
gen consum=cultcon+autcon+indcon
summarize consum if sample==1 & active==1
display r(sum)  // = 303

* Cultural rights concessions 
count if cultcon == 1 & sample==1 & active==1 // = 51

* Autonomy concessions 
count if autcon ==1 & sample==1 & active==1 // = 242

* Independence concessions 
count if indcon ==1 & sample==1 & active==1 // = 10

* Share of SDMs with at least 1 concession
bysort groupid: egen maxcon = max(con) if active == 1
mean maxcon if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 80.07%


* All restrictions
gen ressum=cultres+autres+indres
summarize ressum if sample==1 & active==1
display r(sum)  // = 194

* Cultural rights restrictions
count if cultres == 1 & sample==1 & active==1 // = 44

* Autonomy restrictions
count if autres ==1 & sample==1 & active==1 // = 143

* Independence restrictions
count if indres ==1 & sample==1 & active==1 // = 7

* Share of SDMs with at least 1 restriction
bysort groupid: egen maxres = max(res) if active == 1
mean maxres if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 52.47%



* Claims
* Secession claim in any year
bysort groupid: egen maxsecession_claim = max(secession_claim) if active==1
mean maxsecession_claim if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 46.2%

* Secession claim in first year
mean secession_claim if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 31.45%


* Sovereignty declarations
gen sovdecsum=autdec + subdec + inddec + irrdec
summarize sovdecsum if sample==1 & active==1
display r(sum) // = 56

* Autonomy declarations (broadly defined, including both sub-state secession and autonomy narrowly defined
gen autdecsum=autdec + subdec
summarize autdecsum if sample==1 & active==1
display r(sum) // = 18

* Secession declarations (includes both independence and irredentist declarations)
gen secdecsum=inddec + irrdec
summarize secdecsum if sample==1 & active==1
display r(sum) // = 38

* Share of SDMs with at least 1 declaration
bysort groupid: egen maxsovdec = max(sovdec) if active == 1
mean maxsovdec if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 38.46%


* SDMs with central state access 
gen included = 0 if excluded == 1
replace included = 1 if excluded == 0
bysort groupid: egen maxincl=max(included) if active==1
mean maxincl if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 44.26%


* SDMs with regional autonomy 
bysort groupid: egen maxregaut=max(regaut) if active==1
mean maxregaut if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 50.94%

* SDMs with de-facto independence
bysort groupid: egen maxdfi=max(defacto) if active==1
mean maxdfi if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 9.06%


* Group size 
bysort groupid: egen maxsize=max(groupsize) if active==1
mean maxsize if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 7.33%

* Spatially concentrated SDMs
bysort groupid: egen maxgrc=max(groupcon) if active==1
mean maxgrc if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 75.23%

* SDMs with transborder kin 
bysort groupid: egen maxkin=max(kin) if active==1
replace maxkin = 1 if maxkin == 2
mean maxkin if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 67.6%


* Claimed territory

* Hydrocarbon reserves
bysort groupid: egen maxhyd=max(hydrocarbon) if active==1
mean maxhyd if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 51.45%

* Land border
bysort groupid: egen maxbrd=max(landborder) if active==1
mean maxbrd if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 64.29%

* Seashore
bysort groupid: egen maxssh=max(seashore) if active==1
mean maxssh if active == 1 & sample == 1 & fyphase1 == 1 [pweight=weight] // 47.19%








**********
** Table 3
**********


* Get data
use "Comparisons.dta", replace

*
** MAR vs SDM
*

* Delimit to time period
preserve
keep if year >= 1945 & year <= 2006

* Collapse to country-group format
collapse (firstnm) country ccode group region combined_mar sdm (max) violsd (mean) democratic rich rcode , by(groupid2)

* Was movement in democracy >= 75% of active years?
replace democratic = 1 if democratic >= .75 & democratic != .
replace democratic = 0 if democratic < .75 & democratic != .

* Was movement in rich country >= 75% of active years
replace rich = 1 if rich >= .75 & rich != .
replace rich = 0 if rich < .75 & rich != .

* Label region code
labmask rcode, values(region)

* Country identifiers
egen country1= tag(ccode) if combined_mar == 1
egen countrysdm= tag(ccode) if sdm == 1

* Show values reported in table
tab combined_mar sdm, row missing
tab country1
tab countrysdm
tab rcode if combined_mar == 1
tab rcode if sdm == 1
sum violsd democratic rich if combined_mar == 1
sum violsd democratic rich if sdm == 1

* Restore
restore




*
** CIDCM 03 vs SDM
*


* Delimit to time period
preserve
keep if year >= 1955 & year <= 2002

* Collapse to country-group format
collapse (firstnm) country ccode group region cidcm_2003 sdm (max) violsd (mean) democratic rich rcode , by(groupid2)

* Was movement in democracy >= 75% of active years?
replace democratic = 1 if democratic >= .75 & democratic != .
replace democratic = 0 if democratic < .75 & democratic != .

* Was movement in rich country >= 75% of active years
replace rich = 1 if rich >= .75 & rich != .
replace rich = 0 if rich < .75 & rich != .

* Country identifiers
egen country1= tag(ccode) if cidcm_2003 == 1
egen countrysdm= tag(ccode) if sdm == 1

* Label region code
labmask rcode, values(region)

* Show values reported in table
tab cidcm_2003 sdm, row missing
tab country1
tab countrysdm
tab rcode if cidcm_2003 == 1
tab rcode if sdm == 1
sum violsd democratic rich if cidcm_2003 == 1
sum violsd democratic rich if sdm == 1

* Restore
restore



*
** CIDCM 08 vs SDM
*

* Delimit to time period
preserve
keep if year >= 1955 & year <= 2006

* Collapse to country-group format
collapse (firstnm) country ccode group region cidcm_2008 sdm (max) violsd (mean) democratic rich rcode , by(groupid2)

* Was movement in democracy >= 75% of active years?
replace democratic = 1 if democratic >= .75 & democratic != .
replace democratic = 0 if democratic < .75 & democratic != .

* Was movement in rich country >= 75% of active years
replace rich = 1 if rich >= .75 & rich != .
replace rich = 0 if rich < .75 & rich != .

* Country identifiers
egen country1= tag(ccode) if cidcm_2008 == 1
egen countrysdm= tag(ccode) if sdm == 1

* Label region code
labmask rcode, values(region)

* Show values reported in table
tab cidcm_2008 sdm, row missing
tab country1
tab countrysdm
tab rcode if cidcm_2008 == 1
tab rcode if sdm == 1
sum violsd democratic rich if cidcm_2008 == 1
sum violsd democratic rich if sdm == 1

* Restore
restore



*
** MAR/CIDCM 03/CIDCM 08 combined vs SDM
*

* Identify cases
gen combined_allexceptsdm = 0
replace combined_allexceptsdm = 1 if combined_mar == 1
replace combined_allexceptsdm = 1 if cidcm_2003 == 1
replace combined_allexceptsdm = 1 if cidcm_2008 == 1


* Delimit to time period
preserve
keep if year >= 1945 & year <= 2006

* Collapse to country-group format
collapse (firstnm) country ccode group region combined_allexceptsdm sdm (max) violsd (mean) democratic rich rcode , by(groupid2)

* Was movement in democracy >= 75% of active years?
replace democratic = 1 if democratic >= .75 & democratic != .
replace democratic = 0 if democratic < .75 & democratic != .

* Was movement in rich country >= 75% of active years
replace rich = 1 if rich >= .75 & rich != .
replace rich = 0 if rich < .75 & rich != .

* Country identifiers
egen country1= tag(ccode) if combined_allexceptsdm == 1
egen countrysdm= tag(ccode) if sdm == 1

* Label region code
labmask rcode, values(region)

* Show values reported in table
tab combined_allexceptsdm sdm, row missing
tab country1
tab countrysdm
tab rcode if combined_allexceptsdm == 1
tab rcode if sdm == 1
sum violsd democratic rich if combined_allexceptsdm == 1
sum violsd democratic rich if sdm == 1





**********
** Table 4
**********

* Get data
use "Walter_final.dta", replace

* Define macro
global BWcontrols = "evcombined svcombined auton_combined combinedgproavgfuture evadd svadd traditn2 auton gproavg avg__military_personel__populati political_instability groupcon numsegx polityaverage duration__yrs_until_end_or_2001_"

* Estimation
foreach var of varlist accomm accomm_updated accomm_updated_strict {
oprobit `var' __ethnicgroupsbritchad $BWcontrols if challenge==1
}


	
	
**********
** Table 5
**********

* Get data
use "SDM_final.dta", replace

* Define macros
global CScontrols = "avghydrocarbon avgstrategicvalue avggroupsize avgmilper_pop maxinstab avggroupcon avgkin avgpolity2 maxduration"
global TSCScontrols = "hydrocarbon strategicvalue groupsize milper_pop lag_instab groupcon kin lag_polity2 duration"
global timedep = "_prefail_binaccomm binaccommyears binaccommyears_sq binaccommyears_cu"
global timedep_strict = "_prefail_binstrictaccomm binstrictaccommyears binstrictaccommyears_sq binstrictaccommyears_cu"
global rename = "avgbw_ethnicgroupsbritchad bw_ethnicgroupsbritchad avghydrocarbon hydrocarbon avgstrategicvalue strategicvalue avggroupsize groupsize avgmilper_pop milper_pop maxinstab lag_instab avggroupcon groupcon avgkin kin avgpolity2 lag_polity2 maxduration duration"

* Cross-section
foreach var of varlist maxaccomm maxstrictaccomm {
oprobit `var' avgbw_ethnicgroupsbritchad $CScontrols if fyphase1==1 [pweight=weight], cluster(ccode)
}	

* Time-series cross-section
oprobit accomm bw_ethnicgroupsbritchad $TSCScontrols $timedep [pweight=weight], cluster(ccode)
oprobit strictaccomm bw_ethnicgroupsbritchad $TSCScontrols $timedep_strict [pweight=weight], cluster(ccode)



	
	
	
***********
** Figure 1
***********

use "SDM_final.dta", replace

* Number of active/violent/high-level violent movements per year
collapse (sum) active violsd hviolsd, by(year)
drop if year < 1945

* Zero variable
gen zero = 0

* Draw graph
graph twoway 	(bar active year, sort barwidth(1) fcolor(gs14) lcolor(black))  ///
				(bar violsd year, sort barwidth(1) fcolor(gs8) lcolor(black)) ///
				(bar hviolsd year, sort barwidth(1) fcolor(gs2) lcolor(black)) ///
					, ///
					xscale(nofextend noextend range(1950 2010)) ///
					yscale(nofextend noextend) ///
					xlabel(1950(10)2010, angle(forty_five)) xmtick(1945(10)2005) ///
					ylabel(0(100)400, axis(1) angle(horizontal) nogrid nogextend) ymtick(25(25)375, axis(1) nolabels) ///
					xtitle("", margin(medsmall)) ///
					ytitle("Number of SDMs", axis(1) margin(zero)) ///
					legend(order(1 2 3) label(1 "Non-violent") label(2 "Low-level violent") label(3 "High-level violent") rows(1) pos(6) colgap(*2) symxsize(3) symysize(3) region(lstyle(none) lcolor(white)))  ///
					scheme(s2mono) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
					plotregion(margin(l=3 r=3 b=1 t=5)) ysize(6) xsize(9) scale(1.3) graphregion(margin(zero))
		

		
***********
** Figure 2
***********

* Can be obtained upon request (R-code)




***********
** Figure 3
***********


* Get data
use "SDM_final.dta" , replace

* Drop inactive years and movements no in sample
drop if active == 0
drop if sample == 0 | sample == .

* Generate regime variable
gen regime = 1 if democracy == 1
replace regime = 2 if anocracy == 1
replace regime = 3 if autocracy == 1
label var regime "Regime type"
label define regime 1 "Democracy" 2 "Anocracy" 3 "Autocracy", replace
label values regime regime

* Generate income group variable
gen incomelevel = 1 if rgdppc<4000 & rgdppc != .
replace incomelevel = 2 if rgdppc>=4000 & rgdppc<10000 & rgdppc != .
replace incomelevel = 3 if rgdppc>=10000 & rgdppc != .
label var incomelevel "Income category"
label define incomelevel 1 "Low-income country" 2 "Medium-income country" 3 "High-income country", replace
label values incomelevel incomelevel

* This makes the following code run once for concessions and once for restrictions
foreach var of varlist con res {

* Identify first concessions/restrictions
bysort groupid: egen min`var'year = min(year) if `var' == 1
bysort groupid: egen min`var'yearcl = mean(min`var'year)
gen first`var' = 1
replace first`var' = 0 if year > min`var'yearcl

* Generate time variable
xtset groupid year
gen time`var' = 1 if fyphase1 == 1 | fyphase2 == 1
replace time`var' = 1 if L.`var' == 1 & time`var' == .
replace time`var' = L.time`var' + 1 if time`var' == .

* Generate sequence variable (flagging periods until first concession/restriction, second concession/restriction etc.)
gen `var'years = year if `var' == 1
bysort groupid: egen rank`var'year = rank(`var'year)
gen sequence`var' = 1 if fyphase1 == 1 | fyphase2 == 1
replace sequence`var' = L.rank`var'year + 1 if sequence`var' == .
replace sequence`var' = L.sequence`var' if sequence`var' == .

* Generate new id (country-group-sequence)
gen newid`var' = groupid * 10 + sequence`var'

* Prepare data for survival analysis
stset time`var' [pweight=weight], failure(`var') id(newid`var')
stdes

* Kaplan-Meier (first failures)
sts graph if sequence`var' == 1 & time`var' < 60, failure by(incomelevel) ///
					xscale(nofextend noextend) ///
					yscale(nofextend noextend) ///
					xlabel(0(20)60,) xmtick(5(5)60) ///
					ylabel(0(.25)1, angle(horizontal) nogrid nogextend) ymtick(0(.05)1, axis(1) nolabels) ///
					xtitle("Years", margin(medsmall)) ///
					ytitle("Probability", margin(horiz_bargraph)) ///
					title("Income", margin(medsmall) size(medlarge)) ///
					legend(order(1 2 3) label(1 "Low-income") label(2 "Medium-income") label(3 "High-income") rows(2) colgap(*2) pos(6) region(lstyle(none) lcolor(white) margin(zero)) bmargin(small))  ///
					scheme(s2mono) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
					ysize(6) xsize(7) scale(1.4)

sts graph if sequence`var' == 1 & time`var' < 60, failure by(regime) ///
					xscale(nofextend noextend) ///
					yscale(nofextend noextend) ///
					xlabel(0(20)60,) xmtick(5(5)60) ///
					ylabel(0(.25)1, angle(horizontal) nogrid nogextend) ymtick(0(.05)1, axis(1) nolabels) ///
					xtitle("Years", margin(medsmall)) ///
					ytitle("Probability", margin(small)) ///
					title("Regime type", margin(medsmall) size(medlarge)) ///
					legend(order(1 2 3) label(1 "Democracy") label(2 "Anocracy") label(3 "Autocracy") rows(2) colgap(*2) pos(6) region(lstyle(none) lcolor(white) margin(zero)) bmargin(small))  ///
					scheme(s2mono) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
					ysize(6) xsize(7) scale(1.4)

sts graph if sequence`var' == 1 & time`var' < 60, failure by(prevviolsd) ///
					xscale(nofextend noextend) ///
					yscale(nofextend noextend) ///
					xlabel(0(20)60,) xmtick(5(5)60) ///
					ylabel(0(.25)1, angle(horizontal) nogrid nogextend) ymtick(0(.05)1, axis(1) nolabels) ///
					xtitle("Years", margin(medsmall)) ///
					ytitle("Probability", margin(small)) ///
					title("Previous violence", margin(medsmall) size(medlarge)) ///
					legend(order(1 2) label(1 "No violence") label(2 "Previous violence") rows(2) colgap(*2) pos(6) region(lstyle(none) lcolor(white) margin(zero)) bmargin(small))  ///
					scheme(s2mono) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
					ysize(6) xsize(7) scale(1.4)
}



***********
** Figure 4
***********

use "Walter_final.dta", replace
keep if maxaccomm != . & accomm != . & maxstrictaccomm != .
gen n = _n
sum n
global n = r(max)
gen z = 1
gen ACCOMM = accomm
gen expand = 2
expand expand, gen(dupl)
replace ACCOMM = maxaccomm if dupl == 1
replace z = 2 if dupl == 1
replace expand = 1 if dupl == 1
drop dupl
expand expand, gen(dupl)
replace ACCOMM = maxstrictaccomm if dupl == 1
replace z= 3 if dupl == 1

label define z 1 "Walter" 2 "SDM" 3 "SDM (strict version)", replace
label value z z

histogram ACCOMM, by(z, rows(1) note("N = $n", span) graphregion(fcolor(white) lcolor(white)) scale(*1.3)) ///
	subtitle(, margin(small) fcolor(gs12) lcolor(gs12) justification(center) alignment(middle)) ///
	discrete percent  fcolor(gs12) lcolor(gs0) ///
	xlabel(0 "None" 1 "Reform" 2 "Autonomy" 3 "Independence", angle(forty_five)) ///
	xscale(nofextend noextend range(0 3)) ///
	yscale(nofextend) ///
	ylabel(0(25)100, axis(1) angle(horizontal) nogrid nogextend) ymtick(0(5)100, axis(1) nolabels) ///
	xtitle("",) ///
	scheme(s2mono) ysize(6) xsize(12) scale(1.3) graphregion(margin(zero)) 


log close
