

*		************************************************************************		*
*		************************************************************************		*
*		  File:				supplement.do												*
*		  Date:				May 2017													*
*		  Purpose:			Tables/Figures reported in supplement (SDM)					*
*		  Log file:			supplement.log												*
*		  Stata version:	14															*
*		************************************************************************		*
*		************************************************************************		*




***************
** Preparations
***************


* Set directory
cd "D:\Dropbox\SD Movements\SDM_Walter\JCR\Supplementary materials\Replication" /* Set to respective directory */

* Log
capture log close
log using "supplement.log", replace

* Packages
ssc install labutil2, replace 

* Define macros
global FLrhs = "lrgdppc lpop lmtnest ncontig Oil nwstate polity2 ethfrac relfrac"
global BWcontrols = "evcombined svcombined auton_combined combinedgproavgfuture evadd svadd traditn2 auton gproavg avg__military_personel__populati political_instability groupcon numsegx polityaverage duration__yrs_until_end_or_2001_"
global BWaltgroupcounts = "avgfearon_numgrps avgamar_agg avggroupcount_al avgepr_relevant avgepr_concentr avgnumbsdms"
global BWlogaltgroupcounts = "log_ethnicgroupsbritchad avglog_fearon_numgrps avglog_amar_agg avglog_groupcount_al avglog_epr_relevant avglog_epr_concentr avglog_numbsdms"
global CScontrols = "avghydrocarbon avgstrategicvalue avggroupsize avgmilper_pop maxinstab avggroupcon avgkin avgpolity2 maxduration"
global TSCScontrols = "hydrocarbon strategicvalue groupsize milper_pop lag_instab groupcon kin lag_polity2 duration"
global CSaddcontrols = "avgloggdpcap avglogmtnest minfederal maxproportional regaut defacto excluded secession_claim maxpostcoldwar"
global TSCSaddcontrols = "lag_loggdpcap logmtnest lag_federal lag_proportional regaut defacto excluded secession_claim postcoldwar lag_hviolsd_past3years lag_lviolsd_past3years"
global altgroupcountsCS = "avgfearon_numgrps avgamar_agg avggroupcount_al avgepr_relevant avgepr_concentr avgnumbsdms"
global logaltgroupcountsCS = "log_walter avglog_fearon_numgrps avglog_amar_agg avglog_groupcount_al avglog_epr_relevant avglog_epr_concentr avglog_numbsdms"
global altgroupcountsTSCS = "fearon_numgrps amar_agg groupcount_al epr_relevant epr_concentr lag_numbsdms"
global logaltgroupcountsTSCS = "bw_log_ethnicgroupsbritchad log_fearon_numgrps log_amar_agg log_groupcount_al log_epr_relevant log_epr_concentr lag_log_numbsdms"
global timedep = "_prefail_binaccomm binaccommyears binaccommyears_sq binaccommyears_cu"
global timedep_strict = "_prefail_binstrictaccomm binstrictaccommyears binstrictaccommyears_sq binstrictaccommyears_cu"
global timedep_only23 = "_prefail_binaccomm_only23 binaccomm_only23years binaccomm_only23years_sq binaccomm_only23years_cu"
global timedep_only23strict = "_prefail_binstrictaccomm_only23 binstrictaccomm_only23years binstrictaccomm_only23years_sq binstrictaccomm_only23years_cu"




***********
** Table S1
***********


* Get data
use "SDM_final.dta", replace

* Income
gen incomelevel = 1 if rgdppc<4000 & rgdppc != .
replace incomelevel = 2 if rgdppc>=4000 & rgdppc<10000 & rgdppc != .
replace incomelevel = 3 if rgdppc>=10000 & rgdppc != .
label var incomelevel "Income category"
label define incomelevel 1 "Low-income country" 2 "Medium-income country" 3 "High-income country", replace
label values incomelevel incomelevel
mean con res if active == 1 & incomelevel == 1 [pweight=weight]
mean con res if active == 1 & incomelevel == 2 [pweight=weight]
mean con res if active == 1 & incomelevel == 3 [pweight=weight]



* Regime type 
gen regime = 1 if democracy == 1
replace regime = 2 if anocracy == 1
replace regime = 3 if autocracy == 1
label var regime "Regime type"
label define regime 1 "Democracy" 2 "Anocracy" 3 "Autocracy", replace
label values regime regime
mean con res if active == 1 & regime == 1 [pweight=weight]
mean con res if active == 1 & regime == 2 [pweight=weight]
mean con res if active == 1 & regime == 3 [pweight=weight]


* Previous violence
mean con res if active == 1 & prevviolsd == 1 [pweight=weight]
mean con res if active == 1 & prevviolsd == 0 [pweight=weight]






***********
** Table S2
***********


* Get data
use "Comparisons.dta", replace


* Harmonize aggregation differences (e.g. SDM codes 5 indigenous groups in the US while MAR only codes a single umbrella group --> keep only one of the indigenous groups included in SDM)

* Canada: Indigenous peoples
drop if country == "Canada" & group == "Cree"
drop if country == "Canada" & group == "Dene"
drop if country == "Canada" & group == "Haida"
drop if country == "Canada" & group == "Innu"
drop if country == "Canada" & group == "Inuit"

* Chile: Indigenous peoples
drop if country == "Chile" & group == "Easter Islanders (Rapa Nui)"

* India: Scheduled Tribes (Both MAR and CIDCM include an umbrella scheduled tribe group but also code individual scheduled tribes as separatist, such as the Nagas. Thus, we only remove "excess" groups that are not coded by any of the other datasets.)
drop if country == "India" & group == "Meghalayans"
drop if country == "India" & group == "Rabhas"
drop if country == "India" & group == "Sikkimese"

* Myanmar: Hill Tribals
drop if country == "Myanmar" & group == "Kokang"
drop if country == "Myanmar" & group == "Lahu"
drop if country == "Myanmar" & group == "Nagas"
drop if country == "Myanmar" & group == "Pa-O"
drop if country == "Myanmar" & group == "Palaung"

* Nicaragua: Indigenous peoples
drop if country == "Nicaragua" & group == "Sumos (Mayangnas)"

* Panama: Indigenous peoples
drop if country == "Panama" & group == "Embera-Wounaan"
drop if country == "Panama" & group == "Ngoebe-Bugle"

* United States: Native Americans
drop if country == "United States" & group == "Cherokee"
drop if country == "United States" & group == "Dine (Navajo)"
drop if country == "United States" & group == "Iroquois"
drop if country == "United States" & group == "Lakota (Sioux)"


* Delimit time period
keep if year >= 1945 & year <= 2006

* Collapse
collapse (max) sdm combined_mar violsd (mean) democratic rich if sdm == 1, by(groupid2)

* Was movement in democracy >= 75% of active years?
replace democratic = 1 if democratic >= .75 & democratic != .
replace democratic = 0 if democratic < .75 & democratic != .

* Was movement in rich country >= 75% of active years
replace rich = 1 if rich >= .75 & rich != .
replace rich = 0 if rich < .75 & rich != .

* Estimate model
logit combined_mar violsd if sdm == 1
logit combined_mar democratic if sdm == 1
logit combined_mar rich if sdm == 1
logit combined_mar violsd democratic rich if sdm == 1


	
***********
** Table S3
***********


* Get data
use "Comparisons.dta", replace


* Harmonize aggregation differences (e.g. SDM codes 5 indigenous groups in the US while MAR only codes a single umbrella group --> keep only one of the indigenous groups included in SDM)

* Canada: Indigenous peoples
drop if country == "Canada" & group == "Cree"
drop if country == "Canada" & group == "Dene"
drop if country == "Canada" & group == "Haida"
drop if country == "Canada" & group == "Innu"
drop if country == "Canada" & group == "Inuit"

* Chile: Indigenous peoples
drop if country == "Chile" & group == "Easter Islanders (Rapa Nui)"

* Colombia: Indigenous peoples
drop if country == "Colombia" & group == "Cacarica"

* India: Scheduled Tribes (Both MAR and CIDCM include an umbrella scheduled tribe group but also code individual scheduled tribes as separatist, such as the Nagas. Thus, we only remove "excess" groups that are not coded by any of the other datasets.)
drop if country == "India" & group == "Meghalayans"
drop if country == "India" & group == "Rabhas"
drop if country == "India" & group == "Sikkimese"

* Mexico: Indigenous peoples
drop if country == "Mexico" & group == "Zapotecs"
drop if country == "Mexico" & group == "Other Indigenous Peoples"

* Nicaragua: Indigenous peoples
drop if country == "Nicaragua" & group == "Sumos (Mayangnas)"

* United States: Native Americans
drop if country == "United States" & group == "Cherokee"
drop if country == "United States" & group == "Dine (Navajo)"
drop if country == "United States" & group == "Iroquois"
drop if country == "United States" & group == "Lakota (Sioux)"


* Delimit time period
keep if year >= 1955 & year <= 2002

* Collapse
collapse (max) sdm cidcm_2003 violsd (mean) democratic rich if sdm == 1, by(groupid2)

* Was movement in democracy >= 75% of active years?
replace democratic = 1 if democratic >= .75 & democratic != .
replace democratic = 0 if democratic < .75 & democratic != .

* Was movement in rich country >= 75% of active years
replace rich = 1 if rich >= .75 & rich != .
replace rich = 0 if rich < .75 & rich != .

* Estimate model
logit cidcm_2003 violsd if sdm == 1
logit cidcm_2003 democratic if sdm == 1
logit cidcm_2003 rich if sdm == 1
logit cidcm_2003 violsd democratic rich if sdm == 1

	
***********
** Table S4
***********


* Get data
use "Comparisons.dta", replace


* Harmonize aggregation differences (e.g. SDM codes 5 indigenous groups in the US while MAR only codes a single umbrella group --> keep only one of the indigenous groups included in SDM)

* Canada: Indigenous peoples
drop if country == "Canada" & group == "Cree"
drop if country == "Canada" & group == "Dene"
drop if country == "Canada" & group == "Haida"
drop if country == "Canada" & group == "Innu"
drop if country == "Canada" & group == "Inuit"

* Chile: Indigenous peoples
drop if country == "Chile" & group == "Easter Islanders (Rapa Nui)"

* Colombia: Indigenous peoples
drop if country == "Colombia" & group == "Cacarica"

* India: Scheduled Tribes (Both MAR and CIDCM include an umbrella scheduled tribe group but also code individual scheduled tribes as separatist, such as the Nagas. Thus, we only remove "excess" groups that are not coded by any of the other datasets.)
drop if country == "India" & group == "Meghalayans"
drop if country == "India" & group == "Rabhas"
drop if country == "India" & group == "Sikkimese"

* Italy: Northerners
drop if country == "Italy" & group == "Emilians"
drop if country == "Italy" & group == "Ligurians"
drop if country == "Italy" & group == "Piedmontese"
drop if country == "Italy" & group == "Romanians"
drop if country == "Italy" & group == "Trentini"
drop if country == "Italy" & group == "Triestines"
drop if country == "Italy" & group == "Tuscans"
drop if country == "Italy" & group == "Venetians"

* Mexico: Indigenous peoples
drop if country == "Mexico" & group == "Zapotecs"
drop if country == "Mexico" & group == "Other Indigenous Peoples"

* Nicaragua: Indigenous peoples
drop if country == "Nicaragua" & group == "Sumos (Mayangnas)"

* United States: Native Americans
drop if country == "United States" & group == "Cherokee"
drop if country == "United States" & group == "Dine (Navajo)"
drop if country == "United States" & group == "Iroquois"
drop if country == "United States" & group == "Lakota (Sioux)"

* Delimit time period
keep if year >= 1955 & year <= 2006

* Collapse
collapse (max) sdm cidcm_2008 violsd (mean) democratic rich  if sdm == 1, by(groupid2)

* Was movement in democracy >= 75% of active years?
replace democratic = 1 if democratic >= .75 & democratic != .
replace democratic = 0 if democratic < .75 & democratic != .

* Was movement in rich country >= 75% of active years
replace rich = 1 if rich >= .75 & rich != .
replace rich = 0 if rich < .75 & rich != .

* Estimate model
logit cidcm_2008 violsd if sdm == 1
logit cidcm_2008 democratic if sdm == 1
logit cidcm_2008 rich if sdm == 1
logit cidcm_2008 violsd democratic rich if sdm == 1



***********
** Table S5
***********


* Open dataset
use "FL_numbsdms.dta", replace


* 1955-1999

* Define minimum year
bysort ccode: egen minyear = min(year) if year >= 1955

* Estimate models
foreach var of varlist tsdm_5599 tcombined_mar_5599 tcidcm_2003_5599 tcidcm_2008_5599 {
nbreg `var' $FLrhs if year == minyear
}


* 1955-1979

* Define minimum year
bysort ccode: egen minyear2 = min(year) if year >= 1955 & year <= 1979

* Estimate models
foreach var of varlist tsdm_5579 tcombined_mar_5579 tcidcm_2003_5579 tcidcm_2008_5579 {
nbreg `var' $FLrhs if year == minyear
}



* 1980-1999

* Define minimum year
bysort ccode: egen minyear3 = min(year) if year >= 1980 & year <= 1999

* Estimate models
foreach var of varlist tsdm_8099 tcombined_mar_8099 tcidcm_2003_8099 tcidcm_2008_8099 {
nbreg `var' $FLrhs if year == minyear3 
}




***********
** Table S6
***********

* Get data
use "Comparisons.dta", replace

* Delimit to time period (1956-2002)
keep if year >= 1956 & year <= 2002

* Collapse to country-group format
collapse (firstnm) country ccode group region walter_model sdm (max) violsd (mean) democratic rich rcode , by(groupid2)

* Was movement in democracy >= 75% of active years?
replace democratic = 1 if democratic >= .75 & democratic != .
replace democratic = 0 if democratic < .75 & democratic != .

* Was movement in rich country >= 75% of active years
replace rich = 1 if rich >= .75 & rich != .
replace rich = 0 if rich < .75 & rich != .

* Country identifiers
egen country1= tag(ccode) if walter_model == 1
egen countrysdm= tag(ccode) if sdm == 1

* Label region code
labmask rcode, values(region)

* Show values reported in table
tab walter_model sdm, row missing
tab country1
tab countrysdm
tab rcode if walter_model == 1
tab rcode if sdm == 1
sum violsd democratic rich if walter_model == 1
sum violsd democratic rich if sdm == 1




***********
** Table S7
***********

* Get data
use "Walter_final.dta", replace

* Estimation
oprobit accomm __ethnicgroupsbritchad $BWcontrols if challenge==1 & ccode != 750
oprobit accomm __ethnicgroupsbritchad $BWcontrols if challenge==1, cluster(ccode)
foreach var of varlist $BWaltgroupcounts $BWlogaltgroupcounts {
oprobit accomm `var' $BWcontrols if challenge==1
}




***********
** Table S8
***********

* Get data
use "SDM_final.dta", replace

* Bivariate regressions
foreach var of varlist maxaccomm maxstrictaccomm {
oprobit `var' avgbw_ethnicgroupsbritchad if fyphase1==1 [pweight=weight], cluster(ccode)
}
oprobit accomm bw_ethnicgroupsbritchad $timedep [pweight=weight], cluster(ccode)
oprobit strictaccomm bw_ethnicgroupsbritchad $timedep_strict [pweight=weight], cluster(ccode)

* Dropping India
foreach var of varlist maxaccomm maxstrictaccomm {
oprobit `var' avgbw_ethnicgroupsbritchad $CScontrols if fyphase1==1 & ccode != 750 [pweight=weight], cluster(ccode)
}	
oprobit accomm bw_ethnicgroupsbritchad $TSCScontrols $timedep if ccode != 750 [pweight=weight], cluster(ccode)
oprobit strictaccomm bw_ethnicgroupsbritchad $TSCScontrols $timedep_strict if ccode != 750 [pweight=weight], cluster(ccode)

* Added controls
foreach var of varlist maxaccomm maxstrictaccomm {
oprobit `var' avgbw_ethnicgroupsbritchad $CScontrols $CSaddcontrols if fyphase1==1 [pweight=weight], cluster(ccode)
}
oprobit accomm bw_ethnicgroupsbritchad $TSCScontrols $TSCSaddcontrols $timedep [pweight=weight], cluster(ccode)
oprobit strictaccomm bw_ethnicgroupsbritchad $TSCScontrols $TSCSaddcontrols $timedep_strict [pweight=weight], cluster(ccode)



	

***********
** Table S9
***********

* Get data
use "SDM_final.dta", replace

* Binary DV
foreach var of varlist maxbinaccomm maxbinstrictaccomm {
probit `var' avgbw_ethnicgroupsbritchad $CScontrols if fyphase1==1 [pweight=weight], cluster(ccode)
}
probit binaccomm bw_ethnicgroupsbritchad $TSCScontrols $timedep [pweight=weight], cluster(ccode)
probit binstrictaccomm bw_ethnicgroupsbritchad $TSCScontrols $timedep_strict [pweight=weight], cluster(ccode)

* DV that counts only autonomy and cultural rights concessions
foreach var of varlist maxaccomm_only23 maxstrictaccomm_only23 {
oprobit `var' avgbw_ethnicgroupsbritchad $CScontrols if fyphase1==1 [pweight=weight], cluster(ccode)
}	
oprobit accomm_only23 bw_ethnicgroupsbritchad $TSCScontrols $timedep_only23 [pweight=weight], cluster(ccode)
oprobit strictaccomm_only23 bw_ethnicgroupsbritchad $TSCScontrols $timedep_only23strict [pweight=weight], cluster(ccode)

* First failures
probit binaccomm bw_ethnicgroupsbritchad $TSCScontrols $timedep if _prefail_binaccomm == 0 [pweight=weight], cluster(ccode)
probit binstrictaccomm bw_ethnicgroupsbritchad $TSCScontrols $timedep_strict if _prefail_binstrictaccomm == 0 [pweight=weight], cluster(ccode)


	

	
************
** Table S10
************

* Get data
use "SDM_final.dta", replace

* Rename variable (otherwise too long to store estimates)
rename avgbw_log_ethnicgroupsbritchad log_walter

* Estimation
foreach var of varlist $altgroupcountsCS $logaltgroupcountsCS {
oprobit maxaccomm `var' $CScontrols if fyphase1==1 [pweight=weight], cluster(ccode)
}

 

	
************
** Table S11
************

* Get data
use "SDM_final.dta", replace

* Rename variable (otherwise too long to store estimates)
rename avgbw_log_ethnicgroupsbritchad log_walter

* Estimation
foreach var of varlist $altgroupcountsCS $logaltgroupcountsCS {
oprobit maxstrictaccomm `var' $CScontrols if fyphase1==1 [pweight=weight], cluster(ccode)
}

        

************
** Table S12
************

* Get data
use "SDM_final.dta", replace

* Estimation
foreach var of varlist $altgroupcountsTSCS $logaltgroupcountsTSCS {
oprobit accomm `var' $TSCScontrols $timedep [pweight=weight], cluster(ccode)
}



************
** Table S13
************

* Get data
use "SDM_final.dta", replace

* Estimation
foreach var of varlist $altgroupcountsTSCS $logaltgroupcountsTSCS {
oprobit strictaccomm `var' $TSCScontrols $timedep_strict [pweight=weight], cluster(ccode)
}



************
** Table S14
************

* Get data
use "SDM_final.dta", replace	

* Cross-section
oprobit maxaccomm totaldadmin_sm $CScontrols if fyphase1==1 [pweight=weight], cluster(ccode)
oprobit maxstrictaccomm totaldadmin_sm $CScontrols if fyphase1==1 [pweight=weight], cluster(ccode)


* Time-series cross-section
oprobit accomm totaldadmin_sm  $TSCScontrols $timedep [pweight=weight], cluster(ccode)
oprobit strictaccomm totaldadmin_sm  $TSCScontrols $timedep_strict [pweight=weight], cluster(ccode)


* Cross-section (logged variant)
oprobit maxaccomm log_totaldadmin_sm $CScontrols if fyphase1==1 [pweight=weight], cluster(ccode)
oprobit maxstrictaccomm log_totaldadmin_sm $CScontrols if fyphase1==1 [pweight=weight], cluster(ccode)

* Time-series cross-section
oprobit accomm log_totaldadmin_sm $TSCScontrols $timedep [pweight=weight], cluster(ccode)
oprobit strictaccomm log_totaldadmin_sm $TSCScontrols $timedep_strict [pweight=weight], cluster(ccode)

	
	
	
	
************
** Figure S1
************

* Open dataset
use "Comparisons.dta", replace

*  Prepare dataset
gen combined_allexceptsdm = 0
replace combined_allexceptsdm = 1 if combined_mar == 1
replace combined_allexceptsdm = 1 if cidcm_2003 == 1
replace combined_allexceptsdm = 1 if cidcm_2008 == 1
collapse (sum) sdm combined_allexceptsdm, by(year)
drop if year < 1955
drop if year > 1999
gen share = combined_allexceptsdm / sdm * 100



* Draw graph
graph twoway 		(line share year, sort lwidth(thick) lcolor(black) lpattern(solid)) ///
					, ///
					xscale(nofextend noextend range(1950 2000)) ///
					yscale(nofextend noextend) ///
					xlabel(1950(10)2000, angle(forty_five)) xmtick(1950(5)2000) ///
					ylabel(50(10)100, axis(1) angle(horizontal) nogrid nogextend) ymtick(50(5)100, axis(1) nolabels) ///
					xtitle("", margin(medsmall)) ///
					ytitle("Cases in MAR & CIDCM as a" "share of cases in SDM dataset (%)", axis(1) margin(zero)) ///
					scheme(s2mono) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
					ysize(6) xsize(9) scale(1.2)

	
log close
